@@ -20,6 +20,8 @@
 
 #pragma once
 
+#include "config.h"
+
 typedef enum
 {
     DETAIL_LIST,
@@ -72,20 +74,6 @@ typedef enum
         }                                                          \
     } while(0)
 
-#define TDNF_SAFE_FREE_MEMORY(pMemory) \
-    do {                                                           \
-        if (pMemory) {                                             \
-            TDNFFreeMemory(pMemory);                               \
-        }                                                          \
-    } while(0)
-
-#define TDNF_SAFE_FREE_STRINGARRAY(ppArray) \
-    do {                                                           \
-        if (ppArray) {                                             \
-            TDNFFreeStringArray(ppArray);                          \
-        }                                                          \
-    } while(0)
-
 //Misc
 #define TDNF_RPM_EXT                      ".rpm"
 #define TDNF_NAME                         "tdnf"
@@ -135,11 +123,12 @@ typedef enum
 #define TDNF_REPO_METADATA_MARKER         "lastrefresh"
 #define TDNF_REPO_METADATA_FILE_PATH      "repodata/repomd.xml"
 #define TDNF_REPO_METADATA_FILE_NAME      "repomd.xml"
+#define TDNF_REPO_METALINK_FILE_NAME      "metalink"
 
 //Repo defaults
 #define TDNF_DEFAULT_REPO_LOCATION        "/etc/yum.repos.d"
 #define TDNF_DEFAULT_CACHE_LOCATION       "/var/cache/tdnf"
-#define TDNF_DEFAULT_DISTROVERPKG         "photon-release"
+#define TDNF_DEFAULT_DISTROVERPKG         "system-release"
 #define TDNF_DEFAULT_DISTROARCHPKG        "x86_64"
 #define TDNF_RPM_CACHE_DIR_NAME           "rpms"
 #define TDNF_REPODATA_DIR_NAME            "repodata"
@@ -154,7 +143,7 @@ typedef enum
 #define TDNF_SETOPT_VALUE_DUMMY            "opt.dummy.value"
 /* plugin defines */
 #define TDNF_DEFAULT_PLUGINS_ENABLED      0
-#define TDNF_DEFAULT_PLUGIN_PATH          "/usr/lib/tdnf-plugins"
+#define TDNF_DEFAULT_PLUGIN_PATH          SYSTEM_LIBDIR"/tdnf-plugins"
 #define TDNF_DEFAULT_PLUGIN_CONF_PATH     "/etc/tdnf/pluginconf.d"
 #define TDNF_PLUGIN_CONF_EXT              ".conf"
 #define TDNF_PLUGIN_CONF_EXT_LEN          5
@@ -223,4 +212,8 @@ typedef enum
     {ERROR_TDNF_OPERATION_ABORTED, "ERROR_TDNF_OPERATION_ABORTED", "Operation aborted."},\
     {ERROR_TDNF_EVENT_CTXT_ITEM_NOT_FOUND, "ERROR_TDNF_EVENT_CTXT_ITEM_NOT_FOUND", "An event context item was not found. This is usually related to plugin events. Try --noplugins to disable all plugins or --disableplugin=<plugin> to disable a specific one. You can permanently disable an offending plugin by setting enable=0 in the plugin config file."},\
     {ERROR_TDNF_EVENT_CTXT_ITEM_INVALID_TYPE, "ERROR_TDNF_EVENT_CTXT_ITEM_INVALID_TYPE", "An event item type had a mismatch. This is usually related to plugin events. Try --noplugins to disable all plugins or --disableplugin=<plugin> to disable a specific one. You can permanently disable an offending plugin by setting enable=0 in the plugin config file."},\
+    {ERROR_TDNF_NO_GPGKEY_CONF_ENTRY,         "ERROR_TDNF_NO_GPGKEY_CONF_ENTRY",         "gpgkey entry is missing for this repo. please add gpgkey in repo file or use --nogpgcheck to ignore."}, \
+    {ERROR_TDNF_BASEURL_DOES_NOT_EXISTS,             "ERROR_TDNF_BASEURL_DOES_NOT_EXISTS",             "Base URL and Metalink URL not found in the repo file"},\
+    {ERROR_TDNF_CHECKSUM_VALIDATION_FAILED,          "ERROR_TDNF_CHECKSUM_VALIDATION_FAILED",          "Checksum Validation failed for the file downloaded using URL from metalink"},\
+    {ERROR_TDNF_METALINK_RESOURCE_VALIDATION_FAILED, "ERROR_TDNF_METALINK_RESOURCE_VALIDATION_FAILED", "No Resource present in metalink file for file download"},\
 };
